@@ -13,7 +13,27 @@ pkg_error <- function(..., .data = NULL, .class = NULL, .envir = parent.frame(),
   )
 
   if (length(.data)) cnd[names(.data)] <- .data
-  if (length(class)) class(cnd) <- c(.class, class(cnd))
+  if (length(.class)) class(cnd) <- c(.class, class(cnd))
+
+  cnd
+}
+
+pkg_warning <- function(..., .data = NULL, .class = NULL, .envir = parent.frame(),
+                      call. = TRUE) {
+  .hide_from_trace <- TRUE
+  cnd <- new_cond(
+    call. = call.,
+    cli::format_error(
+      .envir = .envir,
+      c(
+        ...
+      )
+    )
+  )
+  class(cnd) <- c(.class, "warning", "condition")
+
+  if (length(.data)) cnd[names(.data)] <- .data
+  if (length(.class)) class(cnd) <- c(.class, class(cnd))
 
   cnd
 }
@@ -22,7 +42,10 @@ stop <- function(..., call. = TRUE, domain = NA) {
   .hide_from_trace <- TRUE
   args <- list(...)
   if (length(args) == 1L && inherits(args[[1L]], "condition")) {
-    throw(args[[1]])
+    throw(
+      add_class(args[[1]], c("rlib_error_3_0", "rlib_error"), "end"),
+      frame = parent.frame()
+    )
   } else {
     throw(new_error(..., call. = call., domain = domain))
   }
