@@ -206,6 +206,9 @@ drop_nulls <- function(x) {
 
 ## R CMD check fixes
 self <- private <- "foobar"
+dummy <- function() {
+  callr::r
+}
 
 get_num_workers <- function() {
   n <- tryCatch(
@@ -292,6 +295,10 @@ async_map <- function(...) {
   asNamespace("pkgcache")$async_map(...)
 }
 
+async_timeout <- function(...) {
+  asNamespace("pkgcache")$async_timeout(...)
+}
+
 download_file <- function(...) {
   asNamespace("pkgcache")$download_file(...)
 }
@@ -320,10 +327,10 @@ get_user_cache_dir <- function(...) {
 
 format_error_with_stdout <- function(x, ...) {
   msg <- conditionMessage(x)
-  if (is.null(x$data$stdout)) {
+  if (is.null(x$stdout)) {
     paste0(msg, " (output not available)")
   } else {
-    out <- last_stdout_lines(x$data$stdout, "stdout + stderr", "OE> ")
+    out <- last_stdout_lines(x$stdout, "stdout + stderr", "OE> ")
     c(paste0(msg, out[1]), out[-1])
   }
 }
@@ -362,6 +369,12 @@ is_windows <- function() {
   identical(tolower(Sys.info()[["sysname"]]), "windows")
 }
 
+# used in coverage condition
+
+is_linux <- function() {
+  identical(tolower(Sys.info()[["sysname"]]), "linux")                # nocov
+}
+
 # This is a workaround for some RStudio bugs:
 # https://github.com/r-lib/pkginstall/issues/42
 # https://github.com/rstudio/rstudio/issues/2387
@@ -451,3 +464,30 @@ pakx_version <- function() {
 remove_entry <- function(l, n) {
   l[names(l) != n]
 }
+
+path_norm <- function(x) {
+  normalizePath(x, mustWork = FALSE)
+}
+
+parse_platform <- function(x) {
+  pcs <- strsplit(x, "-", fixed = TRUE)
+  data_frame(
+    cpu = vcapply(pcs, "[", 1),
+    vendor = vcapply(pcs, "[", 2),
+    os = vcapply(pcs, function(y) {
+      if (length(y) < 3) NA_character_ else paste(y[-(1:2)], collapse = "-")
+    })
+  )
+}
+
+single_quote <- function(x) {
+  encodeString(x, quote = "'", na.encode = FALSE)
+}
+
+backtick <- function(x) {
+  encodeString(x, quote = "`", na.encode = FALSE)
+}
+
+collapse <- function(x, ...) {
+  cli::ansi_collapse(x, ...)
+}
\ No newline at end of file
