@@ -4,5 +4,5 @@ if (Sys.getenv("NOT_CRAN") == "true") {
   library(pkgdepends)
 
   Sys.setenv(R_USER_CACHE_DIR = tempdir())
-  test_check("pkgdepends")
+  test_check("pkgdepends", reporter = "summary")
 }
